@@ -8,6 +8,6 @@ class LogRecordDO(BaseDO):
     log_domain: str
     log_location: str
     log_inhalt: str
-    log_label: List[str]=[]
+    log_label: Optional[List[str]]=None
     log_datetime: Optional[str]=None
     _life_time: Optional[int]=600
\ No newline at end of file
